@@ -1,5 +1,7 @@
 """ Column name definitions """
 
+import pandas
+
 # original, unmodified column names
 POS_X = "Pos.X"
 POS_Y = "Pos.Y"
@@ -121,3 +123,17 @@ INDEX_COLUMNS_POS = (
     WELL_ROW,
     POS_ID,
 )
+
+
+def _cleanup_data_columns(data_frame: pandas.DataFrame) -> pandas.DataFrame:
+    """renames some data columns for consistency and drops unused columns
+
+    Args:
+        data_frame: pandas DataFrame with parsed measurement data
+
+    Returns:
+        pandas DataFrame, column names cleaned up
+    """
+    renamed = data_frame.rename(columns=CSV_RENAME_MAP)
+    surplus_columns = set(renamed.columns) - PARSED_DATA_COLUMN_SET
+    return renamed.drop(columns=surplus_columns)
