@@ -3,9 +3,10 @@
 Parsing the numerical output from Sensovations Sensospot image analysis.
 """
 
+import logging
 import pathlib
-from typing import Any, Dict, Union, Optional
-from xml.etree.ElementTree import Element as ElementType  # noqa: S405
+from typing import Any, Dict, Optional, Union
+from xml.etree.ElementTree import Element as ElementType
 
 import numpy
 import pandas
@@ -15,6 +16,8 @@ from . import columns
 
 PathLike = Union[str, pathlib.Path]
 
+logger = logging.getLogger("sensospot_parser")
+
 
 def _search_params_file(folder: PathLike) -> Optional[pathlib.Path]:
     """searches for a exposure settings file in a folder
@@ -30,10 +33,7 @@ def _search_params_file(folder: PathLike) -> Optional[pathlib.Path]:
     if not params_folder.is_dir():
         return None
     param_files = list(params_folder.glob("**/*.svexp"))
-    if len(param_files) == 1:
-        return param_files[0]
-    else:
-        return None
+    return param_files[0] if len(param_files) == 1 else None
 
 
 def _get_channel_data(channel_node: ElementType) -> Dict[str, Any]:
@@ -45,9 +45,9 @@ def _get_channel_data(channel_node: ElementType) -> Dict[str, Any]:
     Returns:
         dict with the information
     """
-    # child.tag == "ChannelConfig1"
+    # Example "ChannelConfig1"
     exposure_id = int(channel_node.tag[-1])
-    # channel_description == "[Cy3|Cy5] Green"
+    # Example "Cy3 Green"
     description = channel_node.attrib["Description"]
     exposure_channel = description.rsplit(" ", 1)[-1]
     # floats can be used for exposure times, not only ints
@@ -68,6 +68,7 @@ def _parse_measurement_params(params_file: PathLike) -> pandas.DataFrame:
     Returns:
         pandas data frame with the parsed information
     """
+    logger.debug(f"Parsing parameters file {params_file}")
     file_path = pathlib.Path(params_file)
     with file_path.open("r") as file_handle:
         tree = ElementTree.parse(file_handle)
@@ -87,6 +88,7 @@ def get_measurement_params(folder: PathLike) -> Optional[pandas.DataFrame]:
     params_file = _search_params_file(folder)
     if params_file is not None:
         return _parse_measurement_params(params_file)
+    logger.debug(f"Could not locate parameters file in folder {folder}")
     return None
 
 
