@@ -1,6 +1,6 @@
 import pandas
 
-from .conftest import EXAMPLE_DIR_CSV_WO_PARAMS, EXAMPLE_DIR_CSV_WITH_PARAMS
+from .conftest import EXAMPLE_DIR_CSV_WITH_PARAMS, EXAMPLE_DIR_CSV_WO_PARAMS
 
 
 def test_search_params_file_ok(example_dir):
@@ -32,8 +32,8 @@ def test_ssearch_measurement_params_file_parameters_file(tmpdir):
 
 def test_parse_channel_info(example_dir):
     from sensospot_parser.parameters import (
-        _search_params_file,
         _parse_measurement_params,
+        _search_params_file,
     )
 
     params = _search_params_file(example_dir / EXAMPLE_DIR_CSV_WITH_PARAMS)
